package net.sf.corn.gate;

/**
 * This exception class is an generic exception for all Gate related exceptions.
 * It's a coded exception so it's details can be gathered by using {@link #getCategory()} and {@link #getCode()} methods.
 * Both category and code constants are defined in the class as constants. The category of the exception is a derived value 
 * from the code, so there is no setter method defined to set it.
 * @author Serhat Dirik
 */
public class GateException extends Exception{

	private static final long serialVersionUID = 3563944983456221551L;

	public final static transient int CATEGORY_GENERIC = 0;
	public final static transient int CATEGORY_COMPONENT = 1;
	public final static transient int CATEGORY_SECURITY = 2;
	public final static transient int CATEGORY_REGISTRY = 3;
	public final static transient int CATEGORY_SERVICE  = 4;
	
	public final static transient int CODE_GENERIC = 0;
	public final static transient int CODE_GENERIC_CONTEXT_INITIALIZATION = 1;
	public final static transient int CODE_GENERIC_INTERCEPTOR = 2;
	public final static transient int CODE_GENERIC_PARSING = 10;
	public final static transient int CODE_GENERIC_INVALID_ARGUMENT = 11;
	public final static transient int CODE_GENERIC_TRANSFORMATION = 12;
	public final static transient int CODE_GENERIC_CLASS_NOT_FOUND = 13;
	public final static transient int CODE_GENERIC_INVALID_CLASS = 14;
	public final static transient int CODE_COMPONENT_NOT_FOUND = 101;
	public final static transient int CODE_COMPONENT_INITIALIZATION = 102;
	
	public final static transient int CODE_SECURITY_AUTHENTICATION_REQUIRED = 201;
	public final static transient int CODE_SECURITY_NOT_AUTHORIZED = 202;
	public final static transient int CODE_SECURITY_PROTOCOL_SECURITY_REQUIRED = 203;
	
	public final static transient int CODE_REGISTRY_ALREADY_REGISTERED = 301;
	public final static transient int CODE_REGISTRY_NOT_REGISTERED = 302;
	public final static transient int CODE_REGISTRY_OPERATION_NOT_FOUND = 303;
	public final static transient int CODE_REGISTRY_SERVICE_NOT_FOUND = 304;
	public final static transient int CODE_REGISTRY_LOCATOR_NOT_FOUND = 305;
	public final static transient int CODE_REGISTRY_NOT_WELL_DEFINED = 306;
	public final static transient int CODE_REGISTRY_UNEXPECTED = 307;
	
	public final static transient int CODE_SERVICE_EXPECTED = 401;
	public final static transient int CODE_SERVICE_UNEXPECTED = 402;
	public final static transient int CODE_SERVICE_LOCAL_USE_ONLY = 403;
	
	
	private int code = 0;
	private int category=0; 

	public GateException(String message, Throwable cause) {
		super(message, cause);
	}


	public GateException(String message) {
		super(message);
	}
	/**
	 * Sets the error code and category 
	 * @param code error code
	 * @return this
	 */
	public GateException code(int code){
		if(code < 0) return this;
		this.code = code;
		this.category = code < 100 ? 0 : (code / 100);
		return this;
	}

	/**
	 * Gives the code of the exception, the default is 0 which describes a generic exception
	 * @return the code the exception
	 */
	public int getCode() {
		return this.code;
	}
	/**
	 * Gives the category of the exception which is derived from the code
	 * @return The category of the exception
	 */
	public int getCategory(){
		return this.category;
	}
	
}
