package net.sf.corn.gate;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation marks an interface as a service interface and 
 * binds it to a component 
 * @author Serhat Dirik
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface GateService {
	/**
	 * Sets the name of the service
	 * @return name of the service
	 */
	String name();
	/**
	 * Specifies the target component of this service. The value 
	 * of this field is important for underlying locator
	 * @return target component name
	 */
	String componentTarget();
	/**
	 * Specifies the locator by its name
	 * @return name of the locator
	 */
	String locator() default ILocator.DEFAULT_LOCATOR_NAME;
	/**
	 * Specifies the life cycle of the service
	 * @return defined life cycle 
	 */
	ServiceDefinition.ServiceScope scope() default ServiceDefinition.ServiceScope.REQUEST;
	/**
	 * Specifies when to initialize bounded component instance. Eager service
	 * components are initialized when they registered and lazy service components
	 * are initialized when they accessed
	 * @return true if the service behaviour marker as lazy 
	 */
	boolean lazy() default true;
	String description() default "";
	boolean authenticationRequiredToInspect() default false;
	boolean authenticationRequiredToUse() default false;
	
	boolean secureProtocolRequiredToInspect() default false;
	boolean secureProtocolRequiredToUse() default false;
	boolean remoteAccessEnabled() default true;
	
	String[] authorizedRolesToInspect() default {};
	String[] authorizedRolesToUse() default {};
	/**
	 * specifies the extended properties as key-value pairs 
	 * @return list of the extended properties
	 */
	StringPair[] properties() default {};
}
