package net.sf.corn.gate;

import java.util.Set;

import net.sf.corn.gate.IDataStage.Scope;

/**
 * This context implementation simply delegates all method call to 
 * wrapped context inside. It's written to define a base class to 
 * register a context wrapper to Registry. Wrappers are useful if 
 * platform developers need to change default context behaviors partially.
 *  
 * @author Serhat Dirik
 */
public  class WrapperClientContext implements IClientContext {

 	private static final long serialVersionUID = -1760984029441870350L;
    private IClientContext clientContext;
 	
 	public WrapperClientContext(IClientContext clientContext) {
 		if(clientContext == null) {
 			throw new IllegalArgumentException("Null client context is passed!");
 		}
		this.clientContext = clientContext;
	}
 	
	
	public String getClientUser() {
		return clientContext.getClientUser();
	}

	
	public boolean isUserInRole(String role) {
		return clientContext.isUserInRole(role);
	}

	
	public IDataStage getDataStage(Scope type) {
		return clientContext.getDataStage(type);
	}

	
	public String getProtocolName() {
		return clientContext.getProtocolName();
	}

	
	public String getClientNetworkAddr() {
		return clientContext.getClientNetworkAddr();
	}

	
	public int getClientCommunicationPort() {
		return clientContext.getClientCommunicationPort();
	}

	
	public String getClientHostName() {
		return clientContext.getClientHostName();
	}

	
	public boolean isLocal() {
		return clientContext.isLocal();
	}

	
	public boolean isProtocolSecure() {
		return clientContext.isProtocolSecure();
	}


	@Override
	public String getServerName() {
		return clientContext.getServerName();
	}


	@Override
	public int getServerPort() {
		return clientContext.getServerPort();
	}


	@Override
	public String getServerNetworkAddr() {
		return clientContext.getServerNetworkAddr();
	}


	@Override
	public Object getFromResponseHeader(String key) {
		return clientContext.getFromResponseHeader(key);
	}


	@Override
	public Set<String> responseHeaderKeySet() {
		return clientContext.responseHeaderKeySet();
	}


	@Override
	public Object addToResponseHeader(String key, Object value) {
		return clientContext.addToResponseHeader(key, value);
	}


	@Override
	public Object removeFromResponseHeader(String key) {
		return clientContext.removeFromResponseHeader(key);
	}


	@Override
	public boolean containsResponseHeaderKey(String key) {
		return clientContext.containsResponseHeaderKey(key);
	}


	@Override
	public Object getFromRequestHeader(String key) {
		return clientContext.getFromRequestHeader(key);
	}


	@Override
	public Set<String> requestHeaderKeySet() {
		return clientContext.requestHeaderKeySet();
	}

}
